/* eslint-disable @typescript-eslint/no-unused-vars */
/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-03-27 16:03:20
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-03 16:17:20
 * @FilePath: \general-ai-manage\src\components\Header\index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { history } from '@umijs/max';
import type { MenuProps } from 'antd';

import { Menu } from 'antd';

import React, { useEffect, useState } from 'react';
import {
  postUploadWarningStatistics,
  postWarningStatistics,
} from '../../../src/services/realTime/alarmlist';
import './index.less';
import menuFooter from '/public/menuFooter.svg';
import menuLogo from '/public/menuLogo.svg';

export type MenuBarProps = {
  menuData: any[];
};
interface LevelKeysProps {
  key?: string;
  children?: LevelKeysProps[];
}
const getLevelKeys = (items1: LevelKeysProps[]) => {
  const key: Record<string, number> = {};
  const func = (items2: LevelKeysProps[], level = 1) => {
    items2.forEach((item) => {
      if (item.key) {
        key[item.key] = level;
      }
      if (item.children) {
        return func(item.children, level + 1);
      }
    });
  };
  func(items1);
  return key;
};
const MenuBar: React.FC<MenuBarProps> = ({ menuData }) => {
  const levelKeys = getLevelKeys(menuData as LevelKeysProps[]);

  // const tabRouter = (record) => {
  //   console.log('tabRouter_record', record);
  //   const currRouteItem =
  //     record.routes && Array.isArray(record.routes) && record.routes.length
  //       ? record.routes[0]
  //       : record;
  //   history.push(currRouteItem.path);
  // };

  // const menuClick = ({ item, key, keyPath, domEvent }) => {
  //   console.log("menuClick", item, key, keyPath, domEvent);
  // };
  const [selectedMenu, setSelectedMenu] = useState([]);
  // const [stateOpenKeys, setStateOpenKeys] = useState(
  //   ()=>{
  //     return JSON.parse(localStorage.getItem('openKeys')) || ['1', '2'];
  //   });
  const [stateOpenKeys, setStateOpenKeys] = useState(['1', '2']);

  // 根据路径查找对应的菜单项
  const findMenuByPath = (menuData: any, pathname: any) => {
    for (const item of menuData) {
      if (item.path === pathname) {
        return item;
      }
      if (item.children) {
        const matchedChild: any = findMenuByPath(item.children, pathname);
        if (matchedChild) {
          return matchedChild;
        }
      }
    }
    return null;
  };
  // 轮询告警信息
  const [isHaveWarning, setIsHaveWarning] = useState(false);
  const [isUploadHaveWarning, setIsUploadHaveWarning] = useState(false);
  const [totalResults, setTotalResults] = useState([]);
  const pollServer = () => {
    postWarningStatistics({})
      .then((res) => {
        let have_warning = res.data.have_warning;
        console.log(res.data.have_warning, 'pollServer');
        // let totalResults = res.data.total_results;
        // setTotalResults(totalResults);
        setIsHaveWarning(() => have_warning);
        // setTimeout(pollServer, 5000);
      })
      .catch(() => {});
    postUploadWarningStatistics({})
      .then((res) => {
        let have_warning = res.data.have_warning;
        console.log(res.data.have_warning, 'pollServer');
        // let totalResults = res.data.total_results;
        // setTotalResults(totalResults);
        setIsUploadHaveWarning(() => have_warning);
        setTimeout(pollServer, 50000);
      })
      .catch(() => {});
  };
  useEffect(() => {
    pollServer();
  }, []);
  // useEffect(() => {
  //   console.log(isHaveWarning,'isHaveWarning');
  // },[isHaveWarning])
  // 当路由变化时更新当前选中菜单项
  useEffect(() => {
    const pathname = history.location.pathname;
    const matchedMenu = findMenuByPath(menuData, pathname);
    if (matchedMenu) {
      setSelectedMenu([matchedMenu.key]);
    }
  }, [menuData, history.location.pathname]);

  console.log(menuData, 'menuData');
  const menuClick: MenuProps['onClick'] = (menuItem) => {
    console.log('Clicked menuItem:', menuItem);
    // Check if menuItem has route defined
    if (menuItem && menuItem.path) {
      history.push(menuItem.path);
      // history.push(
      //   menuItem.path,
      //   {totalResults});
    }
    // console.log('menuClick ', e.item.props.path);
    // const currRouteItem = e.item.props;
    // history.push(currRouteItem.path);
  };
  const onOpenChange: MenuProps['onOpenChange'] = (openKeys) => {
    console.log(openKeys, 'openKeys');
    const currentOpenKey = openKeys.find((key) => stateOpenKeys.indexOf(key) === -1);
    console.log(currentOpenKey, 'currentOpenKey');
    // open
    if (currentOpenKey !== undefined) {
      const repeatIndex = openKeys
        .filter((key) => key !== currentOpenKey)
        .findIndex((key) => levelKeys[key] === levelKeys[currentOpenKey]);

      setStateOpenKeys(
        openKeys
          // remove repeat key
          .filter((_, index) => index !== repeatIndex)
          // remove current level all child
          .filter((key) => levelKeys[key] <= levelKeys[currentOpenKey]),
      );
      localStorage.setItem(
        'openKeys',
        JSON.stringify(
          openKeys
            // remove repeat key
            .filter((_, index) => index !== repeatIndex)
            // remove current level all child
            .filter((key) => levelKeys[key] <= levelKeys[currentOpenKey]),
        ),
      );
    } else {
      // close
      setStateOpenKeys(openKeys);
      localStorage.setItem('openKeys', JSON.stringify(openKeys));
    }
  };
  // useEffect(() => {
  //   // 从本地存储中获取保存的展开菜单项状态
  //   const savedOpenKeys = localStorage.getItem('openKeys');
  //   if (savedOpenKeys) {
  //     setStateOpenKeys(JSON.parse(savedOpenKeys));
  //     // console.log(savedOpenKeys,'savedOpenKeys');
  //   }
  // }, []);
  // useEffect(() => {
  //   console.log(history, 'menu_history');
  // }, []);

  return (
    <div className="flex flex-col items-center justify-between menubar_wrap">
      <div className="menu_top">
        <img src={menuLogo} />
      </div>
      {/* <ul className="menus_box m-[0px]">
          {menuData &&
            menuData.length &&
            menuData.map((item, index) => {
              return (
                <li key={index} className="px-[16px]" onClick={() => tabRouter(item)}>
                  <span>{item.title}</span>
                </li>
              );
            })}
        </ul> */}
      {/* // TODO 菜单需要补充路由聚焦状态  */}
      <div className="menu_center">
        {/* <Menu
          mode="inline"
          theme="dark"
          defaultSelectedKeys={stateOpenKeys}
          // openKeys={menuData}
          selectedKeys={selectedMenu}
          openKeys={stateOpenKeys}
          onOpenChange={onOpenChange}
          items={menuData}
          onClick={menuClick}
        >
          {menuData.map((menuItem) => (
            <Menu.Item key={menuItem.key} icon={<Icon component={menuLogo} />}>
              {menuItem.title}
            </Menu.Item>
          ))}
        </Menu> */}
        <Menu
          mode="inline"
          theme="dark"
          selectedKeys={selectedMenu}
          openKeys={stateOpenKeys}
          onOpenChange={onOpenChange}
        >
          {menuData.map((menuItem) =>
            menuItem.children ? (
              <Menu.SubMenu key={menuItem.key} title={menuItem.title} icon={menuItem.icon}>
                {menuItem.children.map((childItem: any) => (
                  <Menu.Item
                    key={childItem.key}
                    icon={childItem.icon}
                    onClick={() => menuClick(childItem)}
                  >
                    {childItem.title}
                    {childItem.key === '102' && isHaveWarning && (
                      <span
                        style={{
                          display: 'inline-block',
                          marginLeft: 8,
                          width: 10,
                          height: 10,
                          background: '#E54D1F',
                          borderRadius: '50%',
                        }}
                      ></span>
                    )}
                    {childItem.key === '202' && isUploadHaveWarning && (
                      <span
                        style={{
                          display: 'inline-block',
                          marginLeft: 8,
                          width: 10,
                          height: 10,
                          background: '#E54D1F',
                          borderRadius: '50%',
                        }}
                      />
                    )}
                  </Menu.Item>
                ))}
              </Menu.SubMenu>
            ) : (
              <Menu.Item
                key={menuItem.key}
                icon={menuItem.icon}
                onClick={() => menuClick(menuItem)}
              >
                {menuItem.title}
              </Menu.Item>
            ),
          )}
        </Menu>
      </div>
      <div className="menu_bottom">
        <img src={menuFooter} />
      </div>
    </div>
  );
};

export default MenuBar;
