/*
 * @Author: zhoux zhouxia@supervision.ltd
 * @Date: 2023-11-01 13:56:33
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-02 17:57:23
 * @FilePath: \general-ai-platform-web\src\pages\Device\DeviceCategoryList\components\UpdateForm.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { postUploadRecognition } from '@/services/realTime/videoFile';
import { ModalForm, ProForm, ProFormDateTimePicker, ProFormText } from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form, message } from 'antd';
import locale from 'antd/es/date-picker/locale/zh_CN';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
} from '../../../../../config/defaultForm';
import './CaptureForm.less';
export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<API.UpdateVideoParams>;

export type UpdateFormProps = {
  updateModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.UpdateVideoParams>;
  reload: any;
};
const UpdateForm: React.FC<UpdateFormProps> = (props) => {
  const intl = useIntl();
  const [form] = Form.useForm<API.UpdateVideoParams>();

  return (
    <ModalForm<any>
      width={proFormSmallModelWidth}
      title={intl.formatMessage({
        id: 'device.interface_manage.table.list.updatVideoSource',
        defaultMessage: `编辑${props.values.video_name}`,
      })}
      open={props.updateModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => {
          props.handleModal();
        },
        okText: intl.formatMessage({ id: 'common.okText', defaultMessage: '确认' }),
        cancelText: intl.formatMessage({ id: 'common.cancelText', defaultMessage: '取消' }),
        className: 'OfflineDeviceList',
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        console.log(values);
        values.id = props.values.id;
        postUploadRecognition(values)
          .then(() => {
            message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '成功' }));
            props.reload();
          })
          .catch(() => {
            message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '失败' }));
          });

        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="video_name"
          label={
            <span style={{ fontWeight: 'bold' }}>
              <FormattedMessage
                id="device.interface_manage.table.list.videoFileName"
                defaultMessage="视频文件名称"
              />
            </span>
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '请输入',
          })}${intl.formatMessage({
            id: 'device.interface_manage.table.list.videoFileName',
            defaultMessage: '视频文件名称',
          })}`}
          initialValue={props.values.video_name}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="device.interface_manage.table.rule.required.videoFileName"
                  defaultMessage="视频文件名称为必填项"
                />
              ),
            },
          ]}
        />
        <ProFormDateTimePicker
          width={proFormSmallItemStyleProps.width}
          name="start_time"
          label={
            <span style={{ fontWeight: 'bold' }}>
              <FormattedMessage
                id="device.interface_manage.table.list.startTime"
                defaultMessage="开始时间"
              />
            </span>
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '请输入',
          })}${intl.formatMessage({
            id: 'device.interface_manage.table.list.startTime',
            defaultMessage: '开始时间',
          })}`}
          initialValue={props.values.start_time === '' ? null : props.values.start_time}
          required={true}
          fieldProps={{
            locale: locale,
          }}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="device.interface_manage.table.rule.required.startTime"
                  defaultMessage="开始时间为必填项"
                />
              ),
            },
          ]}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default UpdateForm;
