import { getVideoList } from '@/services/realTime/videoFile';
import { ClockCircleOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProCard, ProTable } from '@ant-design/pro-components';
import { FormattedMessage } from '@umijs/max';
import { Button, Tag } from 'antd';
import moment from 'moment';
import React, { useRef, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
import UpdateForm from './components/UpdateForm';
// import './components/CaptureForm.less'
const VideoFile: React.FC = () => {
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  // const intl = useIntl();
  const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);

  const [currentRow, setCurrentRow] = useState<API.UpdateVideoParams>();
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  // const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  // const handleCreateModal = () => {
  //   if (createModalOpen) {
  //     setCreateModalOpen(false);
  //     setCurrentRow(undefined);
  //   } else {
  //     setCreateModalOpen(true);
  //   }
  // };
  // 编辑弹框
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);

  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };

  // 最近拍摄
  // const [captureModalOpen, setCaptureModalOpen] = useState<boolean>(false);

  // const handleCaptureModal = () => {
  //   console.log(captureModalOpen);
  //   if (captureModalOpen) {
  //     setCaptureModalOpen(false);
  //     setCurrentRow(undefined);
  //   } else {
  //     setCaptureModalOpen(true);
  //   }
  // };

  const getStatus = (type: any) => {
    if (type === 1) {
      return '#DCF3D1';
    } else if (type === 2) {
      return '#FDDFD1';
    } else {
      return '#FEEFD0';
    }
  };

  const getFileStatus = (type: any) => {
    if (type === 1) {
      return '#DCF3D1';
    } else if (type === 2) {
      return '#FDDFD1';
    } else {
      return '#CCC';
    }
  };

  const getColorStatus = (type: any) => {
    if (type === 1) {
      return '#52C41A';
    } else if (type === 2) {
      return '#F75F19';
    } else {
      return '#FAAD14';
    }
  };

  const getFileColorStatus = (type: any) => {
    if (type === 1) {
      return '#52C41A';
    } else if (type === 2) {
      return '#F75F19';
    } else {
      return '#FFF';
    }
  };

  const getCharactersStatus = (type: any) => {
    if (type === 1) {
      return '已分析';
    } else if (type === 2) {
      return '待分析';
    } else {
      return '分析中';
    }
  };

  const getFileCharactersStatus = (type: any) => {
    if (type === 1) {
      return '已获取';
    } else if (type === 2) {
      return '待传输';
    } else {
      return '已删除';
    }
  };
  // 测试连接
  // const [loading, setLoading] = useState<boolean>(false);

  const columns: ProColumns<API.UpdateVideoParams>[] = [
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.videoFileName"
          defaultMessage="视频文件名称"
        />
      ),
      dataIndex: 'video_name',
      hideInSearch: true,
    },
    {
      title: (
        <FormattedMessage id="device.interface_manage.table.list.format" defaultMessage="格式" />
      ),
      dataIndex: 'video_type',
      hideInSearch: true,
    },
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.videoDuration"
          defaultMessage="视频时长"
        />
      ),
      dataIndex: 'video_length',
      hideInSearch: true,
    },
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.getTime"
          defaultMessage="获取时间"
        />
      ),
      dataIndex: 'upload_time',
      valueType: 'dateTime',
      hideInSearch: true,
    },
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.analyzeStatus"
          defaultMessage="分析状态"
        />
      ),
      dataIndex: 'is_finished',
      hideInSearch: true,
      render: (dom) => {
        return (
          <div>
            <Tag
              bordered={false}
              color={getStatus(dom)}
              style={{
                height: 24,
                fontSize: 14,
                color: getColorStatus(dom),
              }}
            >
              {getCharactersStatus(dom)}
            </Tag>
          </div>
        );
      },
    },
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.fileStatus"
          defaultMessage="文件状态"
        />
      ),
      dataIndex: 'video_status',
      hideInSearch: true,
      render: (dom) => {
        return (
          <div>
            <Tag
              bordered={false}
              color={getFileStatus(dom)}
              style={{
                height: 24,
                fontSize: 14,
                color: getFileColorStatus(dom),
              }}
            >
              {getFileCharactersStatus(dom)}
            </Tag>
          </div>
        );
      },
    },
    {
      title: (
        <FormattedMessage
          id="device.interface_manage.table.list.videoStartTime"
          defaultMessage="视频起始时间"
        />
      ),
      dataIndex: 'start_time',
      hideInSearch: true,
      // valueType: 'dateTime',
      render: (dom, record) => {
        return (
          <div>
            <Button
              key="update"
              type="link"
              size="small"
              style={{
                color: '#004FB2',
              }}
              icon={<ClockCircleOutlined />}
              onClick={() => {
                setUpdateModalOpen(true);
                setCurrentRow(record);
              }}
            >
              {dom !== '-'
                ? moment(record?.start_time).format('YYYY-MM-DD HH:mm:ss')
                : '定义日期时间'}
            </Button>
          </div>
        );
      },
    },

    // {
    //   title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="操作" />,
    //   dataIndex: 'option',
    //   valueType: 'option',
    //   width: '260px',
    //   fixed: 'right',
    //   render: (_, record) => [
    //     <TableActionCard
    //       key="TableActionCardRef"
    //       renderActions={[
    //         {
    //           key: 'update',
    //           renderDom: (
    //             <Button
    //               key="update"
    //               type="link"
    //               size="small"
    //               style={{
    //                 color: '#004FB2',
    //               }}
    //               icon={
    //                 <EditOutlined
    //                   style={{
    //                     marginRight: 3,
    //                   }}
    //                 />
    //               }
    //               onClick={() => {
    //                 setUpdateModalOpen(true);
    //                 setCurrentRow(record);
    //               }}
    //             >
    //               <FormattedMessage id="common.edit" defaultMessage="编辑" />
    //             </Button>
    //           ),
    //         },
    //         {
    //           key: 'destroy',
    //           renderDom: (
    //             <IsDelete
    //               deleteApi={() => {
    //                 handleDestroy(record).then(() => {});
    //               }}
    //             ></IsDelete>
    //           ),
    //         },
    //       ]}
    //     ></TableActionCard>,
    //   ],
    // },
  ];
  return (
    <PageContainer
      title={false}
      content={
        <div
          style={{
            display: 'flex',
            justifyContent: 'space-between',
          }}
        >
          <div
            style={{
              fontWeight: 600,
              fontSize: 20,
              color: '#333',
            }}
          >
            视频分析
          </div>
          {/* <Button
            type="primary"
            onClick={() => {
              setCreateModalOpen(true);
            }}
          >
            <FormattedMessage
              id="device.interface_manage.table.list.addVideoSource"
              defaultMessage="新建视频源"
            />
          </Button> */}
        </div>
      }
    >
      <ProCard
        style={{ margin: 0, padding: 0, boxShadow: '0px 4px 8px 0px rgba(0,79,178,0.15)' }}
        bodyStyle={{ margin: 0, padding: 0 }}
        headerBordered
        title="视频文件列表"
        // extra={
        //   <Button
        //     type="primary"
        //     style={{
        //       boxShadow: 'none',
        //     }}
        //     onClick={() => {
        //       setCreateModalOpen(true);
        //     }}
        //   >
        //     <FormattedMessage
        //       id="device.interface_manage.table.list.addVideoSource"
        //       defaultMessage="新建视频源"
        //     />
        //   </Button>
        // }
      >
        <ProTable<any>
          cardProps={{
            bodyStyle: {
              padding: 20,
            },
          }}
          className="table_header_bg"
          options={{ fullScreen: false, setting: false, density: false, reload: false }}
          actionRef={actionRef}
          rowKey="key"
          search={false}
          showSorterTooltip={false}
          pagination={{
            ...proTablePaginationOptions,
            pageSize: currentPageSize,
            onChange: (page, pageSize) => setCurrentPageSize(pageSize),
          }}
          columnsState={{
            persistenceKey: 'device_category_list',
            persistenceType: 'localStorage',
          }}
          request={async (params = {}, sort) => {
            const { current, ...rest } = params;
            const reqParams = {
              page: current,
              desc: false,
              orderKey: '',
              ...rest,
            };
            if (sort && Object.keys(sort).length) {
              reqParams.orderKey = Object.keys(sort)[0];
              let sort_select = sort[reqParams.orderKey];
              reqParams.desc = sort_select === 'descend';
            }
            //   let resp = await postDeviceCategoryGetDeviceCategoryList({ ...reqParams });
            let resp = await getVideoList({ ...reqParams });
            return {
              data: resp.data.results.map((v: any) => {
                return { ...v, key: v.id };
              }),
              success: resp.success,
              total: resp.data.count,
              current: resp.data.page,
              pageSize: resp.data.pageSize,
            };
          }}
          columns={columns}
        />
      </ProCard>

      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />
    </PageContainer>
  );
};

export default VideoFile;
