import { postTestDevice, postTestlPatform } from '@/services/realTime/interfaces';
import { useIntl } from '@umijs/max';
import { Button, Tag, message } from 'antd';
import moment from 'moment';
import React, { useState } from 'react';
import { ReactComponent as Refresh } from '../../.../../../../../public/images/icons/refresh.svg';

interface ImageSinglePopoverProps {
  values: any;
  reload: any;
}

const CaptureButton: React.FC<ImageSinglePopoverProps> = (props) => {
  const intl = useIntl();
  const [loading, setLoading] = useState<boolean>(false);
  const connection = () => {
    setLoading(true);
    if (props.values.device_ip) {
      postTestDevice({
        device_ip: props.values.device_ip,
        id: props.values.id,
      })
        .then((res) => {
          if (res.success) {
            message.success(res.msg);
          }
          props.reload();
          setLoading(false);
        })
        .catch(() => {
          message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '失败' }));
          setLoading(false);
        });
    } else {
      postTestlPatform({
        // device_ip: props.values.device_ip,
        id: props.values.id,
      })
        .then((res) => {
          if (res.success) {
            message.success(res.msg);
          }
          props.reload();
          setLoading(false);
        })
        .catch(() => {
          message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '失败' }));
          setLoading(false);
        });
    }
  };

  return (
    <div>
      <Tag
        bordered={false}
        color={props.values.test_result === 1 ? '#52C41A' : '#CCCCCC'}
        style={{
          fontSize: 14,
          height: 24,
          color: '#fff',
        }}
      >
        {props.values.test_result === 1 ? '在线' : '离线'}
      </Tag>
      <span>{moment(props.values.test_time).format('YYYY-MM-DD hh:mm:ss')}</span>
      <Button
        type="link"
        icon={
          <Refresh
            style={{
              display: 'inline-flex',
              alignItems: 'center',
              color: 'inherit',
              fontStyle: 'normal',
              lineHeight: 0,
              textAlign: 'center',
              textTransform: 'none',
              verticalAlign: '-0.2em',
              textRendering: 'optimizeLegibility',
            }}
          />
        }
        loading={loading}
        onClick={() => {
          connection();
        }}
      />
    </div>
  );
};

export default CaptureButton;
